==> gradle_properties-0.1.0.tar.gz: example/gradle_properties_example.dart <==
/*
 * Copyright (c) 2020, Birju Vachhani
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

import 'dart:io';

import 'package:gradle_properties/gradle_properties.dart';

void main() async {
  // load properties file
  final properties = await GradleProperties.fromFile(File('gradle.properties'));

  // use extension to load properties
  await File('gradle.properties').readProperties();

  // load with file path
  await GradleProperties.fromPath('gradle.properties');

  // create new properties from [Map<String, String>]
  await GradleProperties.fromMap(
      {'name': 'Birju', 'email': 'brvachhani@gmail.com'});

  // access properties with keys
  print(properties['email']);

  // check if certain property exists or not
  print(properties.contains('first_name'));

  // modify a property
  properties['first_name'] = 'Birju';

  // saves changes back to the same file
  properties.save();

  // saves changes to a different file
  properties.save(File('test.properties'));

  // access all the keys
  print(properties.keys);

  // access all the values
  print(properties.values);

  // get properties as [Map<String, String>]
  print(properties.properties);

  // add properties from a [Map<String, String>]
  properties
      .addAll({'website': 'birjuvachhani.dev', 'username': 'birjuvachhani'});
}

==> gradle_properties-1.0.1.tar.gz: example/gradle_properties_example.dart <==
/*
 * Copyright (c) 2020, Birju Vachhani
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

import 'dart:io';

import 'package:gradle_properties/gradle_properties.dart';

void main() async {
  // load properties file
  final properties = await GradleProperties.fromFile(File('gradle.properties'));

  // use extension to load properties
  await File('gradle.properties').readProperties();

  // load with file path
  await GradleProperties.fromPath('gradle.properties');

  // create new properties from [Map<String, String>]
  GradleProperties.fromMap({'name': 'Birju', 'email': 'brvachhani@gmail.com'});

  // access properties with keys
  print(properties?['email']);

  // check if certain property exists or not
  print(properties?.contains('first_name'));

  // modify a property
  properties?['first_name'] = 'Birju';

  // saves changes back to the same file
  properties?.save();

  // saves changes to a different file
  properties?.save(File('test.properties'));

  // access all the keys
  print(properties?.keys);

  // access all the values
  print(properties?.values);

  // get properties as [Map<String, String>]
  print(properties?.properties);

  // add properties from a [Map<String, String>]
  properties
      ?.addAll({'website': 'birjuvachhani.dev', 'username': 'birjuvachhani'});
}
